@@ -79,6 +79,7 @@ int ClientGame::init(const string& setname, int levelid)
 	game_set_ball_auto_return( !config.return_on_click );
 	game_set_ball_random_angle( config.random_angle );
 	game_set_ball_accelerated_speed( config.maxballspeed_float );
+	game_set_bcc_type(config.bcc_type);
 	game->ball_auto_speedup = config.ball_auto_turbo;
 	extrasActive = false;
 	pvel = pvelmin;
@@ -391,9 +392,10 @@ const string &ClientGame::getBonusLevelInfo()
 				game->blNumCompletedRuns, game->blMaxScore);
 		break;
 	case LT_DEFENDER:
-		strprintf(info, _("Wave: %d, Invaders: %d/%d"),
+		strprintf(info, _("Wave: %d, Invaders: %d/%d (Active: %d)"),
 				game->blNumCompletedRuns+1,
-				game->blNumInvaders, game->blInvaderLimit);
+				game->blNumKilledInvaders, game->blInvaderLimit,
+				game->blNumInvaders);
 		break;
 	case LT_OUTBREAK:
 		strprintf(info, _("Wave: %d, Infections: %d/%d, Active: %d/%d"),
