@@ -45,7 +45,6 @@ Config::Config()
 	rel_motion = 0;
 	motion_mod = 100;
 	convex = 1;
-	linear_corner = 0;
 	invert = 0;
 	i_key_speed = 600;
 	key_speed = 0.6;
@@ -82,6 +81,7 @@ Config::Config()
 	theme_id = 0;
 	theme_count = 1;
 	edit_setname ="newset";
+	bcc_type = 0; /* trajectory */
 
 	/* if config dir not found create necessary dirs */
 	dname = CONFIGDIR;
@@ -132,7 +132,6 @@ Config::Config()
 	fp.get( "grab", grab );
 	fp.get( "motion_mod", motion_mod );
 	fp.get( "convex", convex );
-	fp.get( "linear_corner", linear_corner );
 	fp.get( "random_angle", random_angle );
 	fp.get( "maxballspeed", maxballspeed_int1000 );
 	maxballspeed_float = (float)maxballspeed_int1000 / 1000;
@@ -158,6 +157,7 @@ Config::Config()
 	fp.get( "theme_id", theme_id );
 	fp.get( "theme_count", theme_count );
 	fp.get( "edit_setname", edit_setname );
+	fp.get( "bcc_type", bcc_type );
 }
 
 void Config::save()
@@ -198,7 +198,6 @@ void Config::save()
 	ofs << "grab=" << grab << "\n";
 	ofs << "motion_mod=" << motion_mod << "\n";
 	ofs << "convex=" << convex << "\n";
-	ofs << "linear_corner=" << linear_corner << "\n";
 	ofs << "random_angle=" << random_angle << "\n";
 	ofs << "maxballspeed=" << maxballspeed_int1000 << "\n";
 	ofs << "invert=" << invert << "\n";
@@ -222,6 +221,7 @@ void Config::save()
 	ofs << "theme_id=" << theme_id << "\n";
 	ofs << "theme_count=" << theme_count << "\n";
 	ofs << "edit_setname=" << edit_setname << "\n";
+	ofs << "bcc_type=" << bcc_type << "\n";
 
 	ofs.close();
 	_loginfo("Configuration saved to %s\n",path.c_str());
