@@ -1282,6 +1282,9 @@ void View::createMenus()
 			_("Maximum speed of accelerated balls."),
 			AID_MAXBALLSPEEDCHANGED,config.maxballspeed_int1000,700,1200,50));
 	mAdv->add(new MenuItemSwitch(_("Bonus Levels"),_("Add bonus levels with a mini game every 4 regular levels. Game over will end the mini game without loosing a life."),AID_NONE,config.add_bonus_levels));
+	mAdv->add(new MenuItemList(_("BCC Type"),
+			_("Ball Collision Check: Get ball targets either by trajectory or clipping."),
+			AID_NONE,config.bcc_type,_("Trajectory"),_("Clipping")));
 	mAdv->add(new MenuItemSep());
 	mAdv->add(new MenuItemBack(mOptions));
 
@@ -1710,6 +1713,32 @@ void View::renderBalls(bool shadow)
 		} else {
 			theme.balls.setAlpha(alpha);
 			theme.balls.copy(type,0,px,py);
+#ifdef WITH_BUG_REPORT
+			if (ball->target.exists) {
+				/* draw trajectory as dotted line, start at target
+				 * and go backwards until ball position is reached;
+				 * also draw ghost ball at target position */
+				int bradius = balls_get_radius();
+				Vec dpos(ball->target.x + bradius,
+						ball->target.y + bradius);
+				Vec dmod(-ball->vel.x,-ball->vel.y);
+				dmod.normalize();
+
+				double pathlen = Vec(ball->target.x - ball->cur.x,
+						ball->target.y - ball->cur.y).getLength();
+
+				for (int i = 0; i < pathlen; i += bradius)  {
+					dpos.add(bradius, dmod);
+					SDL_Rect dotrect = {(int)v2s(dpos.getX())-1,
+							(int)v2s(dpos.getY())-1,2,2};
+					SDL_SetRenderDrawColor(mrc,255,255,255,0.5);
+					SDL_RenderFillRect(mrc, &dotrect);
+				}
+
+				theme.balls.setAlpha(64);
+				theme.balls.copy(type,0,v2s(ball->target.x),v2s(ball->target.y));
+			}
+#endif
 		}
 	}
 }
@@ -1869,6 +1898,7 @@ void View::runBrickDestroyDlg()
 	texty += theme.fNormal.getLineHeight();
 	theme.fSmall.setAlign(ALIGN_X_CENTER | ALIGN_Y_CENTER);
 	theme.fSmall.write(imgBricksX+imgBricks.getWidth()/2, texty,
+				/* xgettext:no-c-format */
 				_("Left-click on any brick to destroy it (costs 10% score)."));
 	texty += theme.fSmall.getLineHeight();
 	theme.fSmall.write(imgBricksX+imgBricks.getWidth()/2, texty,
